#ifndef __MYDATA_H_
#define __MYDATA_H_

// author macro
#define AUTHOR "My Name" 

// pwm data
#define PWM_FREQ (20000) // frequency of the PWM for motor control
#define TMR2_PS (1) // TMR2 prescaler for math 
#define TMR2_PS_VAL (0) // TMR2 prescaler for the register
#define TMR2_PR ((SYS_FREQ/PWM_FREQ/TMR2_PS)-1) // TMR2 period register
#define MAX_WINDUP (3000) // This is the maximum windup for current control
#define COUNTS_PER_REVOLUTION (396) // motor's CPR with 4x quadrature
#define MAX_COUNTS_PER_SECOND (25000) // based on no-load speed
int duty1; // duty cycle for OC1 as counts
int duty1_percent; // duty cycle for OC1 as a percent
int dir; // direction of the DC motor 1 == CW, 0 == CCW

// current data
#define VOLTS_PER_SAMPLE (3.3/1024) // for converting ADC samples to volts
#define ADC_TO_AMPS(v) (0.942*v-1.540) // from calibration
#define SAMPLE_TIME (10) // for letting the ADC comparator settle

// current controller data
#define CURRENT_PIN 11  // pin that OUT on current sensor is attached to
#define CURRENT_AMPLITUDE 0.1 // for setting the amplitude of a
			      // reference current square wave.  Used in
			      // the "itune" mode.
#define TOGGLE_FREQ 2  // for the frequency of the reference current wave
#define CURR_CONTROL_FREQ (5000) // frequency of our current control ISR
#define TMR4_PS (1) // TMR4 prescaler for math 
#define TMR4_PS_VAL (0) // TMR4 prescaler for the register
#define TMR4_PR ((SYS_FREQ/CURR_CONTROL_FREQ/TMR4_PS)-1) // TMR4 period register
float Kp_curr; // proportional gain for the current control loop
float Ki_curr; // integral gain for the current control loop

// motion controller data
#define MOTION_CONTROL_FREQ (250) // frequency of the motion control loop
#define TMR5_PS (8) // TMR5 prescaler for math 
#define TMR5_PS_VAL (3) // TMR5 prescaler for the register
#define TMR5_PR ((SYS_FREQ/MOTION_CONTROL_FREQ/TMR5_PS)-1) // TMR5 period register
#define WINDUP (200) // windup for the motion control loop
#define UMAX (1.5) // maximum current that we are willing to request
#define MOTION_DIVISOR (1000.0) // used for increasing the magnitude of the
				// motion control gains
float Kp;  // proportional gain for motion control loop
float Ki;  // integral gain for the motion control loop

// modes of operation
int mode;
enum mode_types {
  DO_NOTHING,
  TUNE_CURRENT,
  TRACK_POSITION,
  HOLD_POSITION
};

// The following struct is a general way to store array data.  We use
// it for storing things like arrays of currents accumulated in the
// current control loop, and arrays of encoder counts accumulated in the
// motion control loop
#define NMAX 3000 // max length of signals
typedef struct signals_t {
  int index;		// represents the current position in the arrays
  int len;		// total length of the arrays
  float desired;        // current desired value
  float actual;		// current actual value
  float ref[NMAX];	// array of references
  float act[NMAX];	// array of actual values
} Signals;

// create global arrays for encoder counts, currents generated in the
// motion control ISR, and currents generated in the current control ISR
Signals encoder, current, fast_current;
#endif /* _MYDATA_H_ */
